@@ -152,9 +152,7 @@ class AwsSNSHandler:
 class Process:
     def __init__(self, process_details):
         self._detail_type = process_details.get("detail-type")
-        self.__source = process_details.get(
-            "source", "*This is an unknown source. Check where this comes from*"
-        )
+        self.__source = process_details.get("source")
         self.__account = process_details.get("account")
         self.__time = (
             process_details.get("time")
@@ -172,7 +170,7 @@ class Process:
                 self.__source = "AWS Lambda"
 
             self.__job_name = process_details["requestContext"]["functionArn"]
-            self.__severity = process_details["detail"].get("severity")
+            self.__severity = None
             self.__state = (
                 "SUCCEEDED"
                 if process_details["requestContext"]["condition"] == "Success"
@@ -191,6 +189,9 @@ class Process:
             self.__job_run_id = process_details["detail"].get("jobRunId", "Untracked")
             self.__message = process_details["detail"]["message"]
 
+        if not self.__source:
+            self.__source = "*This is an unknown source. Check where this comes from*"
+
     @property
     def detail_type(self):
         return self._detail_type
