@@ -226,3 +226,48 @@ def test_parse_event_sns_key_error_2(mock_event_sns_key_error_2):
 
     assert isinstance(result[2], KeyError)
     assert result[0] == expected_result
+
+
+@pytest.fixture
+def mock_event_sns_lambda_1():
+    event = {
+        "Records": [
+            {
+                "EventSource": "aws:sns",
+                "EventVersion": "1.0",
+                "EventSubscriptionArn": "arn:aws:sns:eu-west-2:309161096106:ProcessesMonitoring:cc124953-2820-4dbe-90de-7c52890512da",
+                "Sns": {
+                    "Type": "Notification",
+                    "MessageId": "129b6aeb-c962-5c4e-b654-3381a75ec42c",
+                    "TopicArn": "arn:aws:sns:eu-west-2:309161096106:ProcessesMonitoring",
+                    "Subject": None,
+                    "Message": '{"version":"1.0","timestamp":"2021-07-15T17:10:20.060Z","requestContext":{"requestId":"f2c12a7e-99d5-4860-9aab-2ea8ec114ab8","functionArn":"arn:aws:lambda:eu-west-2:309161096106:function:ETLGoogleSpreadsheetToDB:$LATEST","condition":"Success","approximateInvokeCount":1},"requestPayload":{  "google_sheets_key": "1ZAchu2BTSHO3kGEuhnrM_IABuZyONucqWfU5SVN-V2w",  "google_sheets_worksheet": "Actioned",  "google_sheets_columns_range": 20,  "google_sheets_columns_remapping": {    "User Ref": "user_id",    "Unblocked": "unblocked"  },  "google_sheets_flag_drop_duplicates": true,  "etl_landing_database": "fraud_db",  "etl_landing_table": "actioned"},"responseContext":{"statusCode":200,"executedVersion":"$LATEST"},"responsePayload":"OK"}',
+                    "Timestamp": "2021-07-15T17:10:20.087Z",
+                    "SignatureVersion": "1",
+                    "Signature": "KpUlXUY3AUi0SwDdtWIyj+FVSMzoNDFNHqxkZQEmoJTqKCBnYwDqzXIzmymc/7o317qFOZNk25GoinccrQ57b0eL9bVVcMqf5HF/T/Ap6+CzQU5DUEIUjIKw1HuL7uuN14AaN1EG1RWc6s4NN17ZB5y3b2w42ro+FLhkblgDpr4W0MduWrK6wrPob71Oua7l19HLSQJ3Wf4hqyP3lkWu04WZcol0psSasD0Cgeb2/iLW4q/rvbBzDbH8JGvYyHTUsnkZYdrrpXQBmwAbDvpjlEbKN7xKXtmfAVyBcf32xvF9aEhavhGbrqygIRam56ScQv+J67L262JS8wYv1xB8Mg==",
+                    "SigningCertUrl": "https://sns.eu-west-2.amazonaws.com/SimpleNotificationService-010a507c1833636cd94bdb98bd93083a.pem",
+                    "UnsubscribeUrl": "https://sns.eu-west-2.amazonaws.com/?Action=Unsubscribe&SubscriptionArn=arn:aws:sns:eu-west-2:309161096106:ProcessesMonitoring:cc124953-2820-4dbe-90de-7c52890512da",
+                    "MessageAttributes": {},
+                },
+            }
+        ]
+    }
+    context = None
+    return event, context
+
+
+def test_parse_event_sns_lambda_1(mock_event_sns_lambda_1):
+    expected_result = (
+        {"statusCode": 200, "body": "ok"},
+        (
+            "AWS Lambda",
+            "arn:aws:lambda:eu-west-2:309161096106:function:ETLGoogleSpreadsheetToDB:$LATEST",
+            "2021-07-15T17:10:20.060Z",
+            "Untracked",
+            "SUCCEEDED",
+            "Lambda function has finished with the following state: SUCCEEDED",
+        ),
+        None,
+    )
+    result = parse_event(*mock_event_sns_lambda_1)
+    assert result == expected_result
